==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/Modules/push-api/ServiceWorkerRegistrationPushAPI.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "Supplementable.h"
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class PushManager;
class ServiceWorkerRegistration;

class ServiceWorkerRegistrationPushAPI : public Supplement<ServiceWorkerRegistration> {
    WTF_MAKE_TZONE_ALLOCATED(ServiceWorkerRegistrationPushAPI);
public:
    explicit ServiceWorkerRegistrationPushAPI(ServiceWorkerRegistration&);
    ~ServiceWorkerRegistrationPushAPI();

    static PushManager& pushManager(ServiceWorkerRegistration&);
    PushManager& pushManager();

private:
    static ServiceWorkerRegistrationPushAPI* from(ServiceWorkerRegistration&);
    static ASCIILiteral supplementName();

    ServiceWorkerRegistration& m_serviceWorkerRegistration;
    const std::unique_ptr<PushManager> m_pushManager;
};

}

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/Modules/push-api/ServiceWorkerRegistrationPushAPI.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "Supplementable.h"
#include <wtf/Forward.h>
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class PushManager;
class ServiceWorkerRegistration;

class ServiceWorkerRegistrationPushAPI : public Supplement<ServiceWorkerRegistration> {
    WTF_MAKE_TZONE_ALLOCATED(ServiceWorkerRegistrationPushAPI);
public:
    explicit ServiceWorkerRegistrationPushAPI(ServiceWorkerRegistration&);
    ~ServiceWorkerRegistrationPushAPI();

    static PushManager& pushManager(ServiceWorkerRegistration&);
    PushManager& pushManager();

private:
    static ServiceWorkerRegistrationPushAPI* from(ServiceWorkerRegistration&);
    static ASCIILiteral supplementName() { return "ServiceWorkerRegistrationPushAPI"_s; }
    bool isServiceWorkerRegistrationPushAPI() const final { return true; }

    ServiceWorkerRegistration& m_serviceWorkerRegistration;
    const std::unique_ptr<PushManager> m_pushManager;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::ServiceWorkerRegistrationPushAPI)
    static bool isType(const WebCore::SupplementBase& supplement) { return supplement.isServiceWorkerRegistrationPushAPI(); }
SPECIALIZE_TYPE_TRAITS_END()
